==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-monitor/lxqt-config-monitor.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../../../fastmenu.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../../../monitorpicture.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="159"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="160"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Inverted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="252"/>
        <source>%1 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%1 second(s) remaining</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-monitor/lxqt-config-monitor.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="255"/>
        <source>%1 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%n second(s) remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
</TS>
